@@ -154,7 +154,7 @@ runBASwebservice_all <- function(handle,
     params = list(USETRN = usetrn),
     oldBasePath = oldBasePath,
     perspective = "default",
-    turnChunkLevelIntoItemLevel = T,
+    turnChunkLevelIntoItemLevel = TRUE,
     func = func,
     patience = patience
   )
@@ -208,8 +208,8 @@ runBASwebservice_all <- function(handle,
   remove_linkDefinition(handle,
                         orthoLevel,
                         mausLevel,
-                        force = T,
-                        verbose = F)
+                        force = TRUE,
+                        verbose = FALSE)
   
   if (running_chunker)
   {
@@ -221,8 +221,8 @@ runBASwebservice_all <- function(handle,
     remove_linkDefinition(handle,
                           transcriptionLevel,
                           orthoAttributeDefinitionName,
-                          force = T,
-                          verbose = F)
+                          force = TRUE,
+                          verbose = FALSE)
   }
   
   handle = bas_clear(handle, oldBasePath, func)
@@ -414,7 +414,7 @@ runBASwebservice_g2pForPronunciation <- function(handle,
 ##'
 ##' When audio input files are longer than approximately 10 minutes, alignment-based segmentation
 ##' tools such as MAUS will take a long time to run. In these cases, the Chunker pre-segments
-##' the input into more digestable "chunks". As input, it requires a word tier with canonical
+##' the input into more digestible "chunks". As input, it requires a word tier with canonical
 ##' pronunciation attributes (which can be derived by \link{runBASwebservice_g2pForPronunciation}).
 ##' The resulting chunk level can be passed as input to \link{runBASwebservice_maus}.
 ##' \strong{This function requires an internet connection.}
